piecash.budget module — Python interface to GnuCash documents 0.15.0 documentation

# piecash.budget module

class `piecash.budget.` `Budget`(*args, **kwargs)

  Bases: `piecash._declbase.DeclarativeBaseGuid`

  A GnuCash Budget

  `name`

    str – name of the budget

  `description`

    str – description of the budget

  `amounts`

    list of `piecash.budget.BudgetAmount` – list of amounts per account

class `piecash.budget.` `BudgetAmount`(*args, **kwargs)

  Bases: `sqlalchemy.ext.declarative.api.DeclarativeBase`

  A GnuCash BudgetAmount

  `amount`

    `decimal.Decimal` – the budgeted amount

  `account`

    `piecash.core.account.Account` – the budgeted account

  `budget`

    `Budget` – the budget of the amount